from setuptools import setup

setup(
    name='zen_quotes',
    packages = ['quotes'],
    version='1.0.1',
    description='A sample lib Zen of Python',
    author='Yuri Mussi',
    author_email='ymussi@gmail.com',
    license='BSD',
    url='https://github.com/ymussi/zen_quotes',
    keywords = [],
    classifiers = [],
    )